<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Duplicate</name>
    <message>
        <source>1 entity duplicated</source>
        <translation type="vanished">1 entita duplikována</translation>
    </message>
    <message>
        <source>%1 entities duplicated</source>
        <translation type="vanished">%1 entit duplikováno</translation>
    </message>
    <message>
        <location filename="../DuplicateInit.js" line="+2"/>
        <source>&amp;Duplicate</source>
        <translation>&amp;Duplikovat</translation>
    </message>
    <message numerus="yes">
        <location filename="../Duplicate.js" line="+54"/>
        <source>%n entity/ies duplicated</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
</TS>
